mapping_test_data = [
    {
        "product": "qt",
        "version": "4.2.3",
        "version_strings": ["Qt 4.2.3", r"QTest library 4.2.3"],
    }
]
package_test_data = [
    {
        "url": "https://kojipkgs.fedoraproject.org//vol/fedora_koji_archive00/packages/qt3/3.3.8b/13.fc9/src/",
        "package_name": "qt3-3.3.8b-13.fc9.src.rpm",
        "product": "qt",
        "version": "3.3.8",
    },
    {
        "url": "http://mirror.centos.org/centos/6/os/x86_64/Packages/",
        "package_name": "qt-x11-4.6.2-28.el6_5.x86_64.rpm",
        "product": "qt",
        "version": "4.6.2",
    },
]
